#
# spec file for package pinfo
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pinfo
Version:        0.6.13
Release:        2.10
Summary:        Lynx-style Info Browser
License:        GPL-2.0-only
Group:          Productivity/Publishing/Texinfo
URL:            https://github.com/baszoetekouw/pinfo
Source:         https://github.com/baszoetekouw/pinfo/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch1:         https://github.com/baszoetekouw/pinfo/commit/16dba5978146b6d3a540ac7c8f415eda49280847.patch
Patch2:         https://github.com/baszoetekouw/pinfo/commit/23c169877fda839f0634b2d193eaf26de290f141.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  ncurses-devel
Requires(post): %{install_info_prereq}
Requires(preun):%{install_info_prereq}

%description
Pinfo is a curses based, Lynx-style info browser.

%prep
%autosetup -p 1

%build
autoreconf -fiv
export CPPFLAGS="-Wno-error=unused-parameter -Wno-error=format"
%configure \
	--with-curses=%{_prefix}
%make_build

%install
%make_install
%find_lang %{name}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%files -f %{name}.lang
%license COPYING
%doc NEWS
%{_mandir}/man1/pinfo.1%{?ext_man}
%{_infodir}/pinfo.info%{?ext_info}
%config %{_sysconfdir}/pinforc
%{_bindir}/pinfo

%changelog
* Fri Oct 22 2021 Marco Strigl <marco.strigl@suse.com>
- added -Wno-error=format to CPPFLAGS to avoid compilation errors
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.6.13:
  - Fix crash on 32-bit architectures
  - minor release to fix the use of defualt colors (COLOR_DEFAULT) on ncurses
    installs; COLOR_DEFAULT values in pinforc were silently ignored, causing
    pinfo to use black-on-balc or white-on-white text
  - remove AM_MAINTAINER_MODE from autoconf scripts to make sure all necessary
    files are always rebuilt on ./configure && make
  - fix possibel buffer overflow (and compiler error with gcc 8.2)
  - Gracefully handle missing indirect info nodes
  - Fix infinite loop when regexp-matching an empty string
  - Fix loading of bare info pages (i.e., without .info extension)
  - Properly load info pages whose name starts with "dir"
  - Changes and tweaks to the auto* build tools
  - Get rid of inlined functions, which break building with gcc7
  - Fix segfautl when closing unopened file
  - Fix typos in docs
  - Fix compiler warnings
  - Fix a number of out-of-buffer write, buffer overflows, string truncations
  - Clean up documentation
  - Correctly handle redirected stdin and/or stdout (https://bugs.debian.org/671306)
  - Fix crash after failed global search
  - Make curses mouse behaviour configurable
    Note: this changes the default behaviour to not capture the mouse. To
    restore the old behaviour, set GRAB-MOUSE=true in pinforc.
  - Avoid an infinite loop for malformed info pages
  - Add readline tab completion for nodes (https://bugs.debian.org/431708)
  - Correct parse node links that span multiple (indented) lines.
  - If a direct info page hit isn't found, try to look up a node in the dir
  - Improve lookup of info pages
  - Fix linking to man pages in a different section
  - Fix the -n/--node command line option
  - Fix issue with handling of suspend/resume and character input
  - New maintainer: Bas Zoetekouw <bas@debian.org>
  - License is now GPL version 2 only
  - Updated German, Dutch, English, Polish, Russian, Czech translations and
    added Basque, Swedish, Viernamese and Brazilian translations.  Thanks to
    Jens Seidel, Rene van Bevern, Piarres Beobide, Krzysztof Krzyzaniak, Yuri
    Kozlov,  Eddy Petrişor, Katarína Machálková, Clytie Siddall and Felipe
    Augusto van de Wiel.
  - Nodes containing a "." are now correctly found
  - Non-ASCII man pages are displayed correctly
  - Improved the history behavior of the search input line
  - Broken tag tables are now automatically fixed
  - Don't segfault when a broken regexp is entered
  - Fixed a number of segfaults caused by using uninitialized pointers and
    off-by-1 errors
  - Fixed heap corruption caused by non-ascii chars in info pages
  - Fixed a lot of patch searching issues
  - Fixed text display on narrow terminals
  - Fixed highlighting of searches
  - The default pinforc now uses the terminal's default foreground and
    background colors.  Thanks to Rob Funk for a patch.
  - Use libreadline by default;  readline version 4 is now required.
  - Better cooperation between ncurses and readline
  - Fixed some memory leaks
  - Got rid of tempnam() calls
  - Fixed -Wall and -Wshadow compiler warnings
  - Use utf8 in documentation files and fixed typoes
- add 16dba5978146b6d3a540ac7c8f415eda49280847.patch
  23c169877fda839f0634b2d193eaf26de290f141.patch: fix build issues with gcc 10
- remove pinfo-0.6.10-tinfo.patch, pinfo-0.6.9-nul-strings.patch
  pinfo-curses-detection.patch: upstream
* Sun Jun 14 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10
- Cleanup spec file with spec-cleaner
* Mon Jan 18 2016 dimstar@opensuse.org
- Add pinfo-curses-detection.patch: Fix detection of ncurses by
  correctly using autoconf.
* Sun Aug  2 2015 mpluskal@suse.com
- Use url for source
- Explicitly depend on autoconf/make
- Update dependencies of info scriplets
- Cleanup spec file with spec-cleaner
* Sat Sep  8 2012 idonmez@suse.com
- Add explicit build dependency on makeinfo
* Fri Nov 25 2011 werner@suse.de
- Help the configure scripot a bit with tinfo from new ncurses API
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Jan 12 2011 puzel@novell.com
- portability fixes (by Pascal)
* Mon Sep 20 2010 puzel@novell.com
- update to pinfo-0.6.10
  - Fix issue with handling of suspend/resume and character input
    (thanks to Scott Mcdermott for the patch)
- drop pinfo-0.6.9-ncursesw.patch (not needed)
* Fri Jun 19 2009 coolo@novell.com
- disable as-needed for this package as it fails to build with it
* Thu Jan 10 2008 mrueckert@suse.de
- updated ncurses patch to stop it from looking for the wrong header
  files
* Tue May 29 2007 anosek@suse.cz
- updated to version 0.6.9
  * Nodes containing a "." are now correctly found
  * Non-ASCII man pages are displayed correctly
  * Improved the history behavior of the search input line
  * Broken tag tables are now automatically fixed
  * Don't segfault when a broken regexp is entered
  * Fixed a number of segfaults caused by using uninitialized
    pointers and off-by-1 errors
  * Fixed heap corruption caused by non-ascii chars in info pages
  * Fixed a lot of patch searching issues
  * Fixed text display on narrow terminals
  * Fixed highlighting of searches
  * The default pinforc now uses the terminal's default foreground
    and background colors.  Thanks to Rob Funk for a patch.
  * Use libreadline by default;  readline version 4 is now required
  * Better cooperation between ncurses and readline
  * Fixed some memory leaks
  * Got rid of tempnam() calls
  * Use utf8 in documentation files and fixed typoes
- fixed corrupted unicode characters in status line [#264229]
  (ncursesw.patch)
- using %%find_lang macro in spec file
* Thu Mar 29 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Aug 17 2005 mmarek@suse.cz
- Fixed a heap corruption bug caused by lines starting with NUL byte
  (#94768)
* Thu Aug 12 2004 mmj@suse.de
- Update to version 0.6.8
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Thu Feb 13 2003 mmj@suse.de
- Use %%install_info macro [#23449]
* Sun Jan 12 2003 tcrhak@suse.cz
- update to version 0.6.6p1
* Fri Dec 14 2001 tcrhak@suse.cz
- update to version 0.6.4
* Tue Nov 13 2001 tcrhak@suse.cz
- removed aclocal, autoconf and automake
* Fri Aug 17 2001 adostal@suse.cz
- update to 0.6.3 version
- fixed spec to %%build
* Fri Oct 20 2000 smid@suse.cz
- new version 0.6.1
* Fri Sep 29 2000 smid@suse.cz
- new version 0.6.0
* Mon Apr 10 2000 smid@suse.cz
- buildroot added
* Tue Feb 15 2000 kukuk@suse.de
- Move /usr/man -> /usr/share/man
* Fri Dec  3 1999 kukuk@suse.de
- Update to version 0.5.9
* Fri Oct  8 1999 kukuk@suse.de
- Update to version 0.5.8
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jul 12 1999 kukuk@suse.de
- Update to version 0.5.5
* Wed Jun 16 1999 kukuk@suse.de
- Update to version 0.5.4
* Fri Jun  4 1999 kukuk@suse.de
- New.
